@@ -8,10 +8,9 @@
 //! }
 //! ```
 pub mod tegen;
-use tegen::TextGenerator;
 
-fn example() {
-    let tg = TextGenerator::new();
+// fn example() {
+//     let tg = TextGenerator::new();
 
-    println!("{}", tg.generate("{Good {night|morning|evening|day}|Hello|Greetings|Howdy|What's up}, {friend|mate}! {How are you|How's it going}?".to_string()));
-}
+//     println!("{}", tg.generate("{Good {night|morning|evening|day}|Hello|Greetings|Howdy|What's up}, {friend|mate}! {How are you|How's it going}?".to_string()));
+// }
